package org.steveshipway.blueprints.directive;

import java.util.Random;

import org.apache.logging.log4j.Logger;

import net.minecraft.util.BlockPos;
import net.minecraft.world.World;

public class ChanceDirective extends Directive {
	private int percentage = 0;
	private Directive directive = null;
	
	public ChanceDirective(int chance, Directive d, Logger logger) {
		percentage = chance;
		directive = d;
		if( d == null ) {
    		logger.error("No secondary directive given to CHANCE directive");
			return;
		}
		if( chance < 0 || chance > 100 ) {
    		logger.error("Invalid percentage "+chance+" given to CHANCE directive");
			return;
		}
	}
	
	@Override
	public boolean build(World world,BlockPos location, int r, Logger logger) {
		Random rnd = new Random();
		if( directive == null ) {
    		logger.error("No secondary directive given to CHANCE directive");
			return false;
		}
		if( rnd.nextInt(100) < this.percentage ) {
			return directive.build(world,location,r,logger);
		} else {
			return true;
		}
	}
	
	@Override
	public String asText() {
		if( directive == null) {
			return "# CHANCE 0";
		} else {
			return "CHANCE "+percentage+"\n  "+directive.asText();
		}
	}
}
